@@ -19,8 +19,8 @@ the formula `2**bit_number` where `bit_number` is the 0-index bit of interest.
 
 # These imports are here for backwards compatibility
 from astropy.nddata.bitmask import interpret_bit_flags as ap_interpret_bit_flags
-from stcal.dqflags import interpret_bit_flags, dqflags_to_mnemonics
-from stcal.basic_utils import multiple_replace
+from stdatamodels.dqflags import interpret_bit_flags, dqflags_to_mnemonics
+from stdatamodels.basic_utils import multiple_replace
 
 # Pixel-specific flags
 pixel = {'GOOD':             0,      # No bits set, all is good
