@@ -1,5 +1,5 @@
 from .reference import ReferenceFileModel
-from stcal.dynamicdq import dynamic_mask
+from stdatamodels.dynamicdq import dynamic_mask
 from .dqflags import pixel
 
 __all__ = ['MaskModel']
