@@ -18,7 +18,6 @@ from astropy.wcs import WCS
 import asdf
 from asdf.tags.core import NDArrayType
 from asdf import AsdfFile
-from asdf.fits_embed import AsdfInFits
 from asdf import schema as asdf_schema
 
 from . import filetype
@@ -176,7 +175,6 @@ class DataModel(properties.ObjectNode):
         self._schema = mschema.merge_property_trees(schema)
 
         # Provide the object as context to other classes and functions
-        self._ctx = self
         self._parent = None
 
         # Initialize with an empty AsdfFile instance as this is needed for
@@ -301,6 +299,15 @@ class DataModel(properties.ObjectNode):
         # Call hook that sets model properties
         self.on_init(init)
 
+    @property
+    def _ctx(self):
+        # self._ctx is a property to avoid reference cycle that would be
+        # created if we set self._ctx = self
+        # a reference cycle would make DataModel difficult to garbage
+        # collect and could reopen the memory leak issues fixed in
+        # https://github.com/spacetelescope/stdatamodels/pull/109
+        return self
+
     @property
     def crds_observatory(self):
         """
@@ -632,7 +639,7 @@ class DataModel(properties.ObjectNode):
         """
         self.on_save(init)
 
-        hdulist, tree = fits_support.to_fits(self._instance, self._schema)
+        hdulist = fits_support.to_fits(self._instance, self._schema)
         with warnings.catch_warnings():
             warnings.filterwarnings('ignore', message='Card is too long')
             if self._no_asdf_extension:
@@ -642,11 +649,7 @@ class DataModel(properties.ObjectNode):
                 # Avoid this.
                 if "ASDF" in hdulist:
                     del hdulist["ASDF"]
-                # Use HDUList.writeto instead of AsdfInFits.write_to
-                hdulist.writeto(init, *args, **kwargs)
-            else:
-                ff = AsdfInFits(hdulist, tree)
-                ff.write_to(init, *args, **kwargs)
+            hdulist.writeto(init, *args, **kwargs)
 
     @property
     def shape(self):
@@ -1031,7 +1034,7 @@ class DataModel(properties.ObjectNode):
             The type will depend on what libraries are installed on
             this system.
         """
-        hdulist, _ = fits_support.to_fits(self._instance, self._schema)
+        hdulist = fits_support.to_fits(self._instance, self._schema)
         hdu = fits_support.get_hdu(hdulist, hdu_name, index=hdu_ver-1)
         header = hdu.header
         return WCS(header, key=key, relax=True, fix=True)
